@@ -54,24 +54,27 @@ int LYRA2(void *K, uint64_t kLen, const void *pwd, uint64_t pwdlen, const void *
     int64_t window = 2; //Visitation window (used to define which rows can be revisited during Setup)
     int64_t gap = 1; //Modifier to the step, assuming the values 1 or -1
     int64_t i; //auxiliary iteration counter
+    uint64_t *wholeMatrix;
+    uint64_t **memMatrix = malloc(nRows * sizeof (uint64_t*));
+    uint64_t *ptrWord;
     //==========================================================================/
 
     //========== Initializing the Memory Matrix and pointers to it =============//
     //Tries to allocate enough space for the whole memory matrix
     i = (int64_t) ((int64_t) nRows * (int64_t) ROW_LEN_BYTES);
-    unsigned long int *wholeMatrix = malloc(i);
+    
+    wholeMatrix = malloc(i);
     if (wholeMatrix == NULL) {
       return -1;
     }
 	memset(wholeMatrix, 0, i);
 
     //Allocates pointers to each row of the matrix
-    uint64_t **memMatrix = malloc(nRows * sizeof (uint64_t*));
     if (memMatrix == NULL) {
       return -1;
     }
     //Places the pointers in the correct positions
-    uint64_t *ptrWord = wholeMatrix;
+    ptrWord = wholeMatrix;
     for (i = 0; i < nRows; i++) {
       memMatrix[i] = ptrWord;
       ptrWord += ROW_LEN_INT64;
